==> lsp-plugins_1.2.16.orig.tar.gz: lsp-plugins/modules/lsp-plugin-fw/include/lsp-plug.in/plug-fw/ctl/containers/ListBox.h <==
/*
 * Copyright (C) 2024 Linux Studio Plugins Project <https://lsp-plug.in/>
 *           (C) 2024 Vladimir Sadovnikov <sadko4u@gmail.com>
 *
 * This file is part of lsp-plugin-fw
 * Created on: 31 мар. 2024 г.
 *
 * lsp-plugin-fw is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * any later version.
 *
 * lsp-plugin-fw is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with lsp-plugin-fw. If not, see <https://www.gnu.org/licenses/>.
 */


#ifndef LSP_PLUG_IN_PLUG_FW_CTL_CONTAINERS_LISTBOX_H_
#define LSP_PLUG_IN_PLUG_FW_CTL_CONTAINERS_LISTBOX_H_

#ifndef LSP_PLUG_IN_PLUG_FW_CTL_IMPL_
    #error "Use #include <lsp-plug.in/plug-fw/ctl.h>"
#endif /* LSP_PLUG_IN_PLUG_FW_CTL_IMPL_ */

#include <lsp-plug.in/plug-fw/version.h>
#include <lsp-plug.in/tk/tk.h>

namespace lsp
{
    namespace ctl
    {
        /**
         * ComboBox controller
         */
        class ListBox: public Widget
        {
            public:
                static const ctl_class_t metadata;

            protected:
                ctl::Enum           sHScroll;
                ctl::Enum           sVScroll;

            public:
                explicit ListBox(ui::IWrapper *wrapper, tk::ListBox *widget);
                virtual ~ListBox() override;

                virtual status_t    init() override;

            public:
                virtual void        set(ui::UIContext *ctx, const char *name, const char *value) override;
                virtual void        end(ui::UIContext *ctx) override;
        };

    } /* namespace ctl */
} /* namespace lsp */



#endif /* LSP_PLUG_IN_PLUG_FW_CTL_CONTAINERS_LISTBOX_H_ */

==> lsp-plugins_1.2.24.orig.tar.gz: lsp-plugins/modules/lsp-plugin-fw/include/lsp-plug.in/plug-fw/ctl/containers/ListBox.h <==
/*
 * Copyright (C) 2024 Linux Studio Plugins Project <https://lsp-plug.in/>
 *           (C) 2024 Vladimir Sadovnikov <sadko4u@gmail.com>
 *
 * This file is part of lsp-plugin-fw
 * Created on: 31 мар. 2024 г.
 *
 * lsp-plugin-fw is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * any later version.
 *
 * lsp-plugin-fw is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with lsp-plugin-fw. If not, see <https://www.gnu.org/licenses/>.
 */


#ifndef LSP_PLUG_IN_PLUG_FW_CTL_CONTAINERS_LISTBOX_H_
#define LSP_PLUG_IN_PLUG_FW_CTL_CONTAINERS_LISTBOX_H_

#ifndef LSP_PLUG_IN_PLUG_FW_CTL_IMPL_
    #error "Use #include <lsp-plug.in/plug-fw/ctl.h>"
#endif /* LSP_PLUG_IN_PLUG_FW_CTL_IMPL_ */

#include <lsp-plug.in/plug-fw/version.h>
#include <lsp-plug.in/tk/tk.h>

namespace lsp
{
    namespace ctl
    {
        /**
         * ListBox controller
         */
        class ListBox: public Widget
        {
            public:
                static const ctl_class_t metadata;

            protected:
                ctl::Enum           sHScroll;
                ctl::Enum           sVScroll;

            public:
                explicit ListBox(ui::IWrapper *wrapper, tk::ListBox *widget);
                ListBox(const ListBox &) = delete;
                ListBox(ListBox &&) = delete;
                virtual ~ListBox() override;

                ListBox & operator = (const ListBox &) = delete;
                ListBox & operator = (ListBox &&) = delete;

                virtual status_t    init() override;

            public:
                virtual void        set(ui::UIContext *ctx, const char *name, const char *value) override;
                virtual void        end(ui::UIContext *ctx) override;
        };

    } /* namespace ctl */
} /* namespace lsp */



#endif /* LSP_PLUG_IN_PLUG_FW_CTL_CONTAINERS_LISTBOX_H_ */
